==> zio-aws-iotwireless_2.13-5.17.104.9-sources.jar: zio/aws/iotwireless/model/CreateMulticastGroupResponse.scala <==
package zio.aws.iotwireless.model
import zio.aws.iotwireless.model.primitives.{
  MulticastGroupId,
  MulticastGroupArn
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateMulticastGroupResponse(
    arn: Option[MulticastGroupArn] = None,
    id: Option[MulticastGroupId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotwireless.model.CreateMulticastGroupResponse = {
    import CreateMulticastGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotwireless.model.CreateMulticastGroupResponse
      .builder()
      .optionallyWith(
        arn.map(value => MulticastGroupArn.unwrap(value): java.lang.String)
      )(_.arn)
      .optionallyWith(
        id.map(value => MulticastGroupId.unwrap(value): java.lang.String)
      )(_.id)
      .build()
  }
  def asReadOnly
      : zio.aws.iotwireless.model.CreateMulticastGroupResponse.ReadOnly =
    zio.aws.iotwireless.model.CreateMulticastGroupResponse.wrap(buildAwsValue())
}
object CreateMulticastGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotwireless.model.CreateMulticastGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotwireless.model.CreateMulticastGroupResponse =
      zio.aws.iotwireless.model.CreateMulticastGroupResponse(
        arn.map(value => value),
        id.map(value => value)
      )
    def arn: Option[MulticastGroupArn]
    def id: Option[MulticastGroupId]
    def getArn: ZIO[Any, AwsError, MulticastGroupArn] =
      AwsError.unwrapOptionField("arn", arn)
    def getId: ZIO[Any, AwsError, MulticastGroupId] =
      AwsError.unwrapOptionField("id", id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotwireless.model.CreateMulticastGroupResponse
  ) extends zio.aws.iotwireless.model.CreateMulticastGroupResponse.ReadOnly {
    override val arn: Option[MulticastGroupArn] = scala
      .Option(impl.arn())
      .map(value =>
        zio.aws.iotwireless.model.primitives.MulticastGroupArn(value)
      )
    override val id: Option[MulticastGroupId] = scala
      .Option(impl.id())
      .map(value =>
        zio.aws.iotwireless.model.primitives.MulticastGroupId(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotwireless.model.CreateMulticastGroupResponse
  ): zio.aws.iotwireless.model.CreateMulticastGroupResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iotwireless_2.13-7.21.15.3-sources.jar: zio/aws/iotwireless/model/CreateMulticastGroupResponse.scala <==
package zio.aws.iotwireless.model
import zio.aws.iotwireless.model.primitives.{
  MulticastGroupId,
  MulticastGroupArn
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateMulticastGroupResponse(
    arn: Optional[MulticastGroupArn] = Optional.Absent,
    id: Optional[MulticastGroupId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotwireless.model.CreateMulticastGroupResponse = {
    import CreateMulticastGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotwireless.model.CreateMulticastGroupResponse
      .builder()
      .optionallyWith(
        arn.map(value => MulticastGroupArn.unwrap(value): java.lang.String)
      )(_.arn)
      .optionallyWith(
        id.map(value => MulticastGroupId.unwrap(value): java.lang.String)
      )(_.id)
      .build()
  }
  def asReadOnly
      : zio.aws.iotwireless.model.CreateMulticastGroupResponse.ReadOnly =
    zio.aws.iotwireless.model.CreateMulticastGroupResponse.wrap(buildAwsValue())
}
object CreateMulticastGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotwireless.model.CreateMulticastGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotwireless.model.CreateMulticastGroupResponse =
      zio.aws.iotwireless.model.CreateMulticastGroupResponse(
        arn.map(value => value),
        id.map(value => value)
      )
    def arn: Optional[MulticastGroupArn]
    def id: Optional[MulticastGroupId]
    def getArn: ZIO[Any, AwsError, MulticastGroupArn] =
      AwsError.unwrapOptionField("arn", arn)
    def getId: ZIO[Any, AwsError, MulticastGroupId] =
      AwsError.unwrapOptionField("id", id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotwireless.model.CreateMulticastGroupResponse
  ) extends zio.aws.iotwireless.model.CreateMulticastGroupResponse.ReadOnly {
    override val arn: Optional[MulticastGroupArn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value =>
        zio.aws.iotwireless.model.primitives.MulticastGroupArn(value)
      )
    override val id: Optional[MulticastGroupId] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value =>
        zio.aws.iotwireless.model.primitives.MulticastGroupId(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotwireless.model.CreateMulticastGroupResponse
  ): zio.aws.iotwireless.model.CreateMulticastGroupResponse.ReadOnly =
    new Wrapper(impl)
}
